# 🍙 PimpMyRice server

_Work in progress._

Server for [PimpMyRice](https://github.com/daddodev/pimpmyrice)

## Quick start

### Install

#### [Pipx](https://pipx.pypa.io/stable/installation/)

```bash
pipx install pimpmyrice_server
```

### Start server

```bash
pimp-server start
```

## [Documentation](https://pimpmyrice.vercel.app/docs)
